(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'react-cursor-position', 'react-hover-observer', './LensTop', './LensLeft', './LensRight', './LensBottom', './EnlargedImage'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('react-cursor-position'), require('react-hover-observer'), require('./LensTop'), require('./LensLeft'), require('./LensRight'), require('./LensBottom'), require('./EnlargedImage'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.reactCursorPosition, global.reactHoverObserver, global.LensTop, global.LensLeft, global.LensRight, global.LensBottom, global.EnlargedImage);
        global.ReactImageMagnify = mod.exports;
    }
})(this, function (exports, _react, _reactCursorPosition, _reactHoverObserver, _LensTop, _LensLeft, _LensRight, _LensBottom, _EnlargedImage) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    exports.ImageShape = undefined;

    var _react2 = _interopRequireDefault(_react);

    var _reactCursorPosition2 = _interopRequireDefault(_reactCursorPosition);

    var _reactHoverObserver2 = _interopRequireDefault(_reactHoverObserver);

    var _LensTop2 = _interopRequireDefault(_LensTop);

    var _LensLeft2 = _interopRequireDefault(_LensLeft);

    var _LensRight2 = _interopRequireDefault(_LensRight);

    var _LensBottom2 = _interopRequireDefault(_LensBottom);

    var _EnlargedImage2 = _interopRequireDefault(_EnlargedImage);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var ReactImageMagnify = function ReactImageMagnify(_ref) {
        var className = _ref.className;
        var enlargedImageContainerStyle = _ref.enlargedImageContainerStyle;
        var enlargedImageStyle = _ref.enlargedImageStyle;
        var fadeDurationInMs = _ref.fadeDurationInMs;
        var hoverDelayInMs = _ref.hoverDelayInMs;
        var hoverOffDelayInMs = _ref.hoverOffDelayInMs;
        var imageStyle = _ref.imageStyle;
        var largeImage = _ref.largeImage;
        var lensStyle = _ref.lensStyle;
        var smallImage = _ref.smallImage;
        var style = _ref.style;


        var cursorOffset = {
            x: Math.round(smallImage.width / largeImage.width * smallImage.width / 2),
            y: Math.round(smallImage.height / largeImage.height * smallImage.height / 2)
        };
        var defaultLensStyle = { backgroundColor: 'rgba(0,0,0,.4)' };
        var compositLensStyle = Object.assign({}, defaultLensStyle, lensStyle);

        return _react2.default.createElement(
            _reactCursorPosition2.default,
            {
                className: className,
                style: Object.assign({
                    width: smallImage.width + 'px',
                    height: smallImage.height + 'px',
                    cursor: 'crosshair',
                    position: 'relative'
                }, style)
            },
            _react2.default.createElement(
                _reactHoverObserver2.default,
                {
                    hoverDelayInMs: hoverDelayInMs,
                    hoverOffDelayInMs: hoverOffDelayInMs,
                    onMouseEnter: function onMouseEnter(_ref2) {
                        var setIsHovering = _ref2.setIsHovering;
                        return setIsHovering();
                    },
                    onMouseLeave: function onMouseLeave(_ref3) {
                        var unsetIsHovering = _ref3.unsetIsHovering;
                        return unsetIsHovering();
                    },
                    onMouseOver: function onMouseOver(_ref4) {
                        var e = _ref4.e;
                        var unsetIsHovering = _ref4.unsetIsHovering;

                        if (e.target.getAttribute('data-hover') === 'false') {
                            unsetIsHovering();
                        }
                    }
                },
                _react2.default.createElement('img', {
                    src: smallImage.src,
                    alt: smallImage.alt,
                    style: Object.assign({
                        width: smallImage.width + 'px',
                        height: smallImage.height + 'px'
                    }, imageStyle)
                }),
                _react2.default.createElement(_LensTop2.default, {
                    cursorOffset: cursorOffset,
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    style: compositLensStyle
                }),
                _react2.default.createElement(_LensLeft2.default, {
                    cursorOffset: cursorOffset,
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    style: compositLensStyle
                }),
                _react2.default.createElement(_LensRight2.default, {
                    cursorOffset: cursorOffset,
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    style: compositLensStyle
                }),
                _react2.default.createElement(_LensBottom2.default, {
                    cursorOffset: cursorOffset,
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    style: compositLensStyle
                }),
                _react2.default.createElement(_EnlargedImage2.default, {
                    containerStyle: enlargedImageContainerStyle,
                    cursorOffset: cursorOffset,
                    fadeDurationInMs: fadeDurationInMs,
                    imageStyle: enlargedImageStyle,
                    largeImage: largeImage,
                    smallImage: smallImage
                })
            )
        );
    };

    var ImageShape = exports.ImageShape = _react.PropTypes.shape({
        alt: _react.PropTypes.string,
        src: _react.PropTypes.string.isRequired,
        width: _react.PropTypes.number.isRequired,
        height: _react.PropTypes.number.isRequired
    });

    ReactImageMagnify.propTypes = {
        className: _react.PropTypes.string,
        enlargedImageContainerStyle: _react.PropTypes.object,
        enlargedImageStyle: _react.PropTypes.object,
        fadeDurationInMs: _react.PropTypes.number,
        hoverDelayInMs: _react.PropTypes.number,
        hoverOffDelayInMs: _react.PropTypes.number,
        imageStyle: _react.PropTypes.object,
        largeImage: ImageShape,
        lensStyle: _react.PropTypes.object,
        smallImage: ImageShape,
        style: _react.PropTypes.object
    };

    ReactImageMagnify.defaultProps = {
        fadeDurationInMs: 300,
        hoverDelayInMs: 250,
        hoverOffDelayInMs: 150
    };

    exports.default = ReactImageMagnify;
});